@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use utf8;
 use Carp;
@@ -66,7 +66,7 @@ sub sql_fetch_all {
         #    push @fields, $fld;
         #}
         #$class->_mk_ro_accessors(\@fields);
-        $class->_mk_ro_accessors([keys $row]);
+        $class->_mk_ro_accessors([keys %$row]);
         #    if $class->can('_make_columns_accessors') && $class->_make_columns_accessors != 0;
         bless $row, $class;
         push @list, $row;
